.. _todo:

TODO: Outstanding Work
======================

Remaining work for release 1.0

- Provide a mechanism (or at least documentation) for deploying as a service
- add python.logging, put in more detailed logging and remove prints
- document the use of the hardware I have tested

  - UUGear MEGA4 USB hub
  - TP-Link Tapo Smart Plug

- Add tests with mocks for SmartThing and get coverage to 95%

